'use strict'
const React = require('react')
const ipfsAPI = require('ipfs-api')
const fileReaderPullStream = require('filereader-pull-stream')

class App extends React.Component {
  constructor () {
    super()
    this.state = {
      response: null,
      added_file_hash: null
    }
    this.ipfsApi = ipfsAPI('localhost', '5001')

    // bind methods
    this.captureFile = this.captureFile.bind(this)
    this.saveToIpfs = this.saveToIpfs.bind(this)
    this.handleSubmit = this.handleSubmit.bind(this)
  }

  captureFile (event) {
    event.stopPropagation()
    event.preventDefault()
    const files = []
    for (let file of event.target.files) {
      const uploadContent = fileReaderPullStream(file, {chunkSize: 32 * 1024 * 1024})
      files.push({
        path: file.name,
        content: uploadContent
      })
    }
    this.saveToIpfs(files)
  }

  saveToIpfs (files) {
    let ipfsId
    this.ipfsApi.add(files, { wrapWithDirectory: true, progress: (prog) => console.log(`received: ${prog}`) })
      .then((response) => {
        console.log(response)
        if (response.length === files.length+1) {
          ipfsId = response[response.length-1].hash
          console.log(ipfsId)
          this.setState({added_file_hash: ipfsId, response: null})
        } else {
          this.setState({added_file_hash: null, response: JSON.stringify(response)})
        }
      }).catch((err) => {
        console.error(err)
      })
  }

  handleSubmit (event) {
    event.preventDefault()
  }

  render () {
    let error = null;
    if (this.state.response) {
      error =  <code>Invalid response object returned by ipfs.files.api (expected more entries):<pre>{this.state.response}</pre></code>
    }
    return (
      <div>
        <div>
          <ol>
            <li>Download three files from <a href="https://ipfs.io/ipfs/QmUGmyGCJEntjyxgcBmptkZ34k7PsgnCzXPoqwiWBDTK6L">here</a> and save them on your disk</li>
            <li>Try to upload the three files at once via button below</li>
          </ol>
        </div>
        <form id='captureMedia' onSubmit={this.handleSubmit}>
          <input type='file' multiple onChange={this.captureFile} />
        </form>
        <div>
          <a target='_blank'
            href={'https://ipfs.io/ipfs/' + this.state.added_file_hash}>
            {this.state.added_file_hash}
          </a>
          <code><pre>{error}</pre></code>
        </div>
      </div>
    )
  }
}
module.exports = App
